# Welcome to skiba


[![image](https://img.shields.io/pypi/v/skiba.svg)](https://pypi.python.org/pypi/skiba)


**A python package for a foresters to query Google Earth Engine data**


-   Free software: MIT License
-   Documentation: <https://taraskiba.github.io/skiba>

[![ForestSPOT](./files/logo.png)](https://github.com/taraskiba/skiba/tree/main/docs/files/logo.png)
## Features

* 🌎 **Interactive mapping**: Create a map with provided coordinates and customizable basemaps and built-in or specified shapefiles
* 📍 **Coordinate-point queries**: Access and retrieve band values from Google Earth Engine for provided coordinates.
* 🔲 **Hidden coordinate queries**: Access and retrieve band values from Google Earth Engine for geojson polygons, either provided or buffered through __buffer_coordinates__ function
